AvailParams class
Search criteria to prefill the Meili Direct flow. Every field is optional; anything left out keeps the funnel's own default.
Constructors
Properties
- currencyCode → String?
-
final
- driverAge → int?
-
final
- dropoffDate → String?
-
final
- dropoffDateTime → DateTime?
-
final
- dropoffLocation → String?
-
final
- dropoffTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pickupDate → String?
-
final
- pickupDateTime → DateTime?
-
final
- pickupLocation → String?
-
final
- pickupTime → String?
-
final
- residency → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited